==> zio-aws-iot1clickdevices_2.13-5.17.123.2-sources.jar: zio/aws/iot1clickdevices/model/DeviceDescription.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.iot1clickdevices.model.primitives.{
  __doubleMin0Max100,
  __boolean,
  __string
}
import scala.jdk.CollectionConverters._
final case class DeviceDescription(
    arn: Option[__string] = None,
    attributes: Option[Map[__string, __string]] = None,
    deviceId: Option[__string] = None,
    enabled: Option[__boolean] = None,
    remainingLife: Option[__doubleMin0Max100] = None,
    `type`: Option[__string] = None,
    tags: Option[Map[__string, __string]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.DeviceDescription = {
    import DeviceDescription.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.DeviceDescription
      .builder()
      .optionallyWith(
        arn.map(value => __string.unwrap(value): java.lang.String)
      )(_.arn)
      .optionallyWith(
        attributes.map(value =>
          value
            .map({ case (key, value) =>
              (__string.unwrap(key): java.lang.String) -> (__string.unwrap(
                value
              ): java.lang.String)
            })
            .asJava
        )
      )(_.attributes)
      .optionallyWith(
        deviceId.map(value => __string.unwrap(value): java.lang.String)
      )(_.deviceId)
      .optionallyWith(
        enabled.map(value => __boolean.unwrap(value): java.lang.Boolean)
      )(_.enabled)
      .optionallyWith(
        remainingLife.map(value =>
          __doubleMin0Max100.unwrap(value): java.lang.Double
        )
      )(_.remainingLife)
      .optionallyWith(
        `type`.map(value => __string.unwrap(value): java.lang.String)
      )(_.`type`)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (__string.unwrap(key): java.lang.String) -> (__string
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.iot1clickdevices.model.DeviceDescription.ReadOnly =
    zio.aws.iot1clickdevices.model.DeviceDescription.wrap(buildAwsValue())
}
object DeviceDescription {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.DeviceDescription
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.DeviceDescription =
      zio.aws.iot1clickdevices.model.DeviceDescription(
        arn.map(value => value),
        attributes.map(value => value),
        deviceId.map(value => value),
        enabled.map(value => value),
        remainingLife.map(value => value),
        `type`.map(value => value),
        tags.map(value => value)
      )
    def arn: Option[__string]
    def attributes: Option[Map[__string, __string]]
    def deviceId: Option[__string]
    def enabled: Option[__boolean]
    def remainingLife: Option[__doubleMin0Max100]
    def `type`: Option[__string]
    def tags: Option[Map[__string, __string]]
    def getArn: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("arn", arn)
    def getAttributes: ZIO[Any, AwsError, Map[__string, __string]] =
      AwsError.unwrapOptionField("attributes", attributes)
    def getDeviceId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("deviceId", deviceId)
    def getEnabled: ZIO[Any, AwsError, __boolean] =
      AwsError.unwrapOptionField("enabled", enabled)
    def getRemainingLife: ZIO[Any, AwsError, __doubleMin0Max100] =
      AwsError.unwrapOptionField("remainingLife", remainingLife)
    def getType: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("type", `type`)
    def getTags: ZIO[Any, AwsError, Map[__string, __string]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.DeviceDescription
  ) extends zio.aws.iot1clickdevices.model.DeviceDescription.ReadOnly {
    override val arn: Option[__string] = scala
      .Option(impl.arn())
      .map(value => zio.aws.iot1clickdevices.model.primitives.__string(value))
    override val attributes: Option[Map[__string, __string]] = scala
      .Option(impl.attributes())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.iot1clickdevices.model.primitives.__string(
              key
            ) -> zio.aws.iot1clickdevices.model.primitives.__string(value)
          })
          .toMap
      )
    override val deviceId: Option[__string] = scala
      .Option(impl.deviceId())
      .map(value => zio.aws.iot1clickdevices.model.primitives.__string(value))
    override val enabled: Option[__boolean] = scala
      .Option(impl.enabled())
      .map(value => zio.aws.iot1clickdevices.model.primitives.__boolean(value))
    override val remainingLife: Option[__doubleMin0Max100] = scala
      .Option(impl.remainingLife())
      .map(value =>
        zio.aws.iot1clickdevices.model.primitives.__doubleMin0Max100(value)
      )
    override val `type`: Option[__string] = scala
      .Option(impl.`type`())
      .map(value => zio.aws.iot1clickdevices.model.primitives.__string(value))
    override val tags: Option[Map[__string, __string]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.iot1clickdevices.model.primitives.__string(
              key
            ) -> zio.aws.iot1clickdevices.model.primitives.__string(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.DeviceDescription
  ): zio.aws.iot1clickdevices.model.DeviceDescription.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-iot1clickdevices_2.13-5.17.130.8-sources.jar: zio/aws/iot1clickdevices/model/DeviceDescription.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.iot1clickdevices.model.primitives.{
  __doubleMin0Max100,
  __boolean,
  __string
}
import scala.jdk.CollectionConverters._
final case class DeviceDescription(
    arn: Option[__string] = None,
    attributes: Option[Map[__string, __string]] = None,
    deviceId: Option[__string] = None,
    enabled: Option[__boolean] = None,
    remainingLife: Option[__doubleMin0Max100] = None,
    `type`: Option[__string] = None,
    tags: Option[Map[__string, __string]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.DeviceDescription = {
    import DeviceDescription.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.DeviceDescription
      .builder()
      .optionallyWith(arn.map(value => value: java.lang.String))(_.arn)
      .optionallyWith(
        attributes.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.attributes)
      .optionallyWith(deviceId.map(value => value: java.lang.String))(
        _.deviceId
      )
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .optionallyWith(remainingLife.map(value => value: java.lang.Double))(
        _.remainingLife
      )
      .optionallyWith(`type`.map(value => value: java.lang.String))(_.`type`)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.iot1clickdevices.model.DeviceDescription.ReadOnly =
    zio.aws.iot1clickdevices.model.DeviceDescription.wrap(buildAwsValue())
}
object DeviceDescription {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.DeviceDescription
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.DeviceDescription =
      zio.aws.iot1clickdevices.model.DeviceDescription(
        arn.map(value => value),
        attributes.map(value => value),
        deviceId.map(value => value),
        enabled.map(value => value),
        remainingLife.map(value => value),
        `type`.map(value => value),
        tags.map(value => value)
      )
    def arn: Option[__string]
    def attributes: Option[Map[__string, __string]]
    def deviceId: Option[__string]
    def enabled: Option[__boolean]
    def remainingLife: Option[__doubleMin0Max100]
    def `type`: Option[__string]
    def tags: Option[Map[__string, __string]]
    def getArn: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("arn", arn)
    def getAttributes: ZIO[Any, AwsError, Map[__string, __string]] =
      AwsError.unwrapOptionField("attributes", attributes)
    def getDeviceId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("deviceId", deviceId)
    def getEnabled: ZIO[Any, AwsError, __boolean] =
      AwsError.unwrapOptionField("enabled", enabled)
    def getRemainingLife: ZIO[Any, AwsError, __doubleMin0Max100] =
      AwsError.unwrapOptionField("remainingLife", remainingLife)
    def getType: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("type", `type`)
    def getTags: ZIO[Any, AwsError, Map[__string, __string]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.DeviceDescription
  ) extends zio.aws.iot1clickdevices.model.DeviceDescription.ReadOnly {
    override val arn: Option[__string] =
      scala.Option(impl.arn()).map(value => value: __string)
    override val attributes: Option[Map[__string, __string]] = scala
      .Option(impl.attributes())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: __string) -> (value: __string)
          })
          .toMap
      )
    override val deviceId: Option[__string] =
      scala.Option(impl.deviceId()).map(value => value: __string)
    override val enabled: Option[__boolean] =
      scala.Option(impl.enabled()).map(value => value: __boolean)
    override val remainingLife: Option[__doubleMin0Max100] =
      scala.Option(impl.remainingLife()).map(value => value: __doubleMin0Max100)
    override val `type`: Option[__string] =
      scala.Option(impl.`type`()).map(value => value: __string)
    override val tags: Option[Map[__string, __string]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: __string) -> (value: __string)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.DeviceDescription
  ): zio.aws.iot1clickdevices.model.DeviceDescription.ReadOnly = new Wrapper(
    impl
  )
}
